aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/PPC/Tango.PPC.UI
diff options
context:
space:
mode:
authorRoy Ben-Shabat <Roy@Twine-s.com>2018-08-23 09:45:01 +0300
committerRoy Ben-Shabat <Roy@Twine-s.com>2018-08-23 09:45:01 +0300
commit2c8da378c82e5181f0566a564de529ab7ef96f4f (patch)
treed450472402b15fc30d8bd482da348826caf487c5 /Software/Visual_Studio/PPC/Tango.PPC.UI
parent774da535e732ecd5a3737550ef1d35819a1e7fc6 (diff)
downloadTango-2c8da378c82e5181f0566a564de529ab7ef96f4f.tar.gz
Tango-2c8da378c82e5181f0566a564de529ab7ef96f4f.zip
Improvements to machine studio view models and navigation system.
Improvements to tech board selection and edit modes handling.
Diffstat (limited to 'Software/Visual_Studio/PPC/Tango.PPC.UI')
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj4
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/Threading/DefaultDispatcherProvider.cs (renamed from Software/Visual_Studio/PPC/Tango.PPC.UI/Threading/DefaultDispetcherProvider.cs)6
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs2
3 files changed, 6 insertions, 6 deletions
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj b/Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj
index fdaf37c09..2b2752a24 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj
@@ -126,7 +126,7 @@
<Compile Include="Notifications\PendingNotification.cs" />
<Compile Include="PPCApplication\DefaultPPCApplicationManager.cs" />
<Compile Include="Printing\DefaultPrintingManager.cs" />
- <Compile Include="Threading\DefaultDispetcherProvider.cs" />
+ <Compile Include="Threading\DefaultDispatcherProvider.cs" />
<Compile Include="ViewModelLocator.cs" />
<Compile Include="ViewModels\ExternalBridgeViewVM.cs" />
<Compile Include="ViewModels\LayoutViewVM.cs" />
@@ -421,7 +421,7 @@ copy /Y "$(SolutionDir)Referenced Assemblies\vcruntime140d.dll" "$(TargetDir)"</
</PropertyGroup>
<ProjectExtensions>
<VisualStudio>
- <UserProperties BuildVersion_StartDate="2000/1/1" BuildVersion_UseGlobalSettings="False" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" />
+ <UserProperties BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UseGlobalSettings="False" BuildVersion_StartDate="2000/1/1" />
</VisualStudio>
</ProjectExtensions>
</Project> \ No newline at end of file
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs b/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs
index 5c416a289..bec1d2b48 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs
@@ -58,7 +58,7 @@ namespace Tango.PPC.UI
TangoIOC.Default.Unregister<IPrintingManager>();
TangoIOC.Default.Unregister<IConnectivityProvider>();
- TangoIOC.Default.Register<IDispatcherProvider, DefaultDispetcherProvider>(new DefaultDispetcherProvider(Application.Current.Dispatcher));
+ TangoIOC.Default.Register<IDispatcherProvider, DefaultDispatcherProvider>(new DefaultDispatcherProvider(Application.Current.Dispatcher));
TangoIOC.Default.Register<INotificationProvider, DefaultNotificationProvider>();
TangoIOC.Default.Register<IAuthenticationProvider, DefaultAuthenticationProvider>();
TangoIOC.Default.Register<IPPCModuleLoader, DefaultPPCModuleLoader>();
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/Threading/DefaultDispetcherProvider.cs b/Software/Visual_Studio/PPC/Tango.PPC.UI/Threading/DefaultDispatcherProvider.cs
index 0051ca329..940c13052 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/Threading/DefaultDispetcherProvider.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/Threading/DefaultDispatcherProvider.cs
@@ -12,15 +12,15 @@ namespace Tango.PPC.UI.Threading
/// Represents the default PPC <see cref="IDispatcherProvider"/> which will invoke action on the current application dispatcher.
/// </summary>
/// <seealso cref="Tango.PPC.Common.Threading.IDispatcherProvider" />
- public class DefaultDispetcherProvider : IDispatcherProvider
+ public class DefaultDispatcherProvider : IDispatcherProvider
{
private Dispatcher _dispatcher;
/// <summary>
/// Initializes a new instance of the <see cref="DefaultDispetcherProvider"/> class.
/// </summary>
/// <param name="dispatcher">The dispatcher.</param>
- public DefaultDispetcherProvider(Dispatcher dispatcher)
+ public DefaultDispatcherProvider(Dispatcher dispatcher)
{
_dispatcher = dispatcher;
}
@@ -12,15 +12,15 @@ namespace Tango.PPC.UI.Threading
private Dispatcher _dispatcher;
/// <summary>
- /// Initializes a new instance of the <see cref="DefaultDispetcherProvider"/> class.
+ /// Initializes a new instance of the <see cref="DefaultDispatcherProvider"/> class.
/// </summary>
/// <param name="dispatcher">The dispatcher.</param>